==> google-cloud-webrisk-1.8.3.tar.gz: google-cloud-webrisk-1.8.3/google/cloud/webrisk/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.webrisk_v1.services.web_risk_service.async_client import (
    WebRiskServiceAsyncClient,
)
from google.cloud.webrisk_v1.services.web_risk_service.client import (
    WebRiskServiceClient,
)
from google.cloud.webrisk_v1.types.webrisk import (
    CompressionType,
    ComputeThreatListDiffRequest,
    ComputeThreatListDiffResponse,
    CreateSubmissionRequest,
    RawHashes,
    RawIndices,
    RiceDeltaEncoding,
    SearchHashesRequest,
    SearchHashesResponse,
    SearchUrisRequest,
    SearchUrisResponse,
    Submission,
    ThreatEntryAdditions,
    ThreatEntryRemovals,
    ThreatType,
)

__all__ = (
    "WebRiskServiceClient",
    "WebRiskServiceAsyncClient",
    "ComputeThreatListDiffRequest",
    "ComputeThreatListDiffResponse",
    "CreateSubmissionRequest",
    "RawHashes",
    "RawIndices",
    "RiceDeltaEncoding",
    "SearchHashesRequest",
    "SearchHashesResponse",
    "SearchUrisRequest",
    "SearchUrisResponse",
    "Submission",
    "ThreatEntryAdditions",
    "ThreatEntryRemovals",
    "CompressionType",
    "ThreatType",
)

==> google-cloud-webrisk-1.10.1.tar.gz: google-cloud-webrisk-1.10.1/google/cloud/webrisk/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.webrisk import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.webrisk_v1.services.web_risk_service.async_client import (
    WebRiskServiceAsyncClient,
)
from google.cloud.webrisk_v1.services.web_risk_service.client import (
    WebRiskServiceClient,
)
from google.cloud.webrisk_v1.types.webrisk import (
    CompressionType,
    ComputeThreatListDiffRequest,
    ComputeThreatListDiffResponse,
    CreateSubmissionRequest,
    RawHashes,
    RawIndices,
    RiceDeltaEncoding,
    SearchHashesRequest,
    SearchHashesResponse,
    SearchUrisRequest,
    SearchUrisResponse,
    Submission,
    ThreatEntryAdditions,
    ThreatEntryRemovals,
    ThreatType,
)

__all__ = (
    "WebRiskServiceClient",
    "WebRiskServiceAsyncClient",
    "ComputeThreatListDiffRequest",
    "ComputeThreatListDiffResponse",
    "CreateSubmissionRequest",
    "RawHashes",
    "RawIndices",
    "RiceDeltaEncoding",
    "SearchHashesRequest",
    "SearchHashesResponse",
    "SearchUrisRequest",
    "SearchUrisResponse",
    "Submission",
    "ThreatEntryAdditions",
    "ThreatEntryRemovals",
    "CompressionType",
    "ThreatType",
)
